#
# spec file for package qgroundcontrol
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           qgroundcontrol
Version:        4.1.2
Release:        bp156.3.7
Summary:        An operator control unit / ground control software for micro air vehicles
License:        GPL-3.0-only
Group:          Other
URL:            http://www.qgroundcontrol.org/
Source0:        qgroundcontrol-%{version}.tar.xz
Patch2:         fix-install.patch
# ModemManager has the broken design to grab any serial port first
# as background daemon. this breaks any other app which needs to access the device
# on boot up (for firmware update here)
Conflicts:      ModemManager
%if 0%{?fedora_version}
BuildRequires:  python2
BuildRequires:  systemd-devel
%else
BuildRequires:  libqt5-qtlocation-private-headers-devel
%endif

BuildRequires:  pkgconfig(Qt5Charts)
BuildRequires:  pkgconfig(Qt5Core) >= 5.11
BuildRequires:  pkgconfig(Qt5MultimediaWidgets)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Positioning)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5ScriptTools)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5TextToSpeech)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WaylandClient)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(Qt5Qwt6)
%endif

BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  SDL2-devel
BuildRequires:  fdupes
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
BuildRequires:  libicu-devel
BuildRequires:  libsndfile-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig(libudev)

#qml deps
Requires:       libqt5-qtcharts-imports
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols2

%description
QGroundControl is an operator control unit / ground control software
for micro air vehicles. It allows to visualize and control a micro
air vehicle during development and operation, both indoors and
outdoors. With a flexible software architecture, it supports multiple
MAV types/autopilot projects.

%prep
%setup -q
%patch2 -p1
mkdir build

%build
cd build
qmake-qt5 ../qgroundcontrol.pro
make %{?_smp_mflags}

%install
cd build
mkdir -p %{buildroot}/%{_bindir}
mkdir -p %{buildroot}/%{_datadir}/%{name}/
#cp -R release/flightgear %{buildroot}/%{_datadir}/%{name}/
install -p -m 755 staging/QGroundControl %{buildroot}/%{_bindir}/
mkdir -p %{buildroot}/usr/share/{applications,pixmaps}
install -p -m 0644 staging/qgroundcontrol.desktop %{buildroot}/usr/share/applications/
install -p -m 0644 staging/qgroundcontrol.png %{buildroot}/usr/share/pixmaps/
sed -i -e 's/^Categories=.*/Categories=System;HardwareSettings;/' %{buildroot}/usr/share/applications/qgroundcontrol.desktop
%fdupes %{buildroot}%{_prefix}

%files
%license COPYING.md
%doc README.md
%attr(0755,root,root) %{_bindir}/QGroundControl
%{_datadir}/%{name}
/usr/share/applications/*
/usr/share/pixmaps/*

%changelog
* Thu Apr  1 2021 Adrian Schröter <adrian@suse.de>
- update to version 4.1.2
  * Bug: Radio setup - Fix double send of `MAV_CMD_PREFLIGHT_CALIBRATION` causing
    "Unable to send command" error.
  * Bug: Fly View - Pause - Fix "Unable to send command" error.
  * Fix TCP link comms
* Mon Mar 29 2021 Christophe Giboudeaux <christophe@krop.fr>
- Remove the unneeded QtWebKitWidgets dependency.
* Sun Jan 17 2021 Adrian Schröter <adrian@suse.de>
- update to version 4.1.0
  * Support simple cameras which only support DIGICAM_CONTROL in the Photo/Video control on Fly View.
  * Load Parameters From File: Support loading parameters which don't currently existing on the vehicle.
  * Load Parameters From File: Add dialog which shows diff of file and vehicle params. Selective param upload from file.
  * Video Streaming: New camera control supports capturing individual images from the stream
  * Fly: Press and hold on arm button will change it to Force Arm. Click again to force arm.
  * VTOL: General setting for transition distance which affects Plan takeoff, landing pattern creation
  * VTOL: Much better VTOL support throughout QGC
  * Maps: Support zoom up to level 23 even if map provider doesn't provide tiles that high
  * Settings/Mavlink: Add ability to forward mavlink traffic out specified UDP port
  * Support mavlink terrain protocol which queries gcs for terrain height information. Allows planning missions with TERRAIN\_FRAME.
  * Fly: New instrument values display/editing support
  * Plan: Added new VTOL Landing Pattern support
  * Plan: Much better conversion of missions to KML for 3d visualization/verification of missions
  * Plan: New Terrain Profile display including terrain collision indications on profile and in patterns (Survey, CorridorScan, etc)
  * Fly: Rearchitect view and controls within for much better customization support in custom builds
* Wed Jan  6 2021 Adrian Schröter <adrian@suse.de>
- update to version 4.0.11
  * Fix battery id handling for multiple batteries
  * Fix Google Play store upload which was preventing new Stables being updated correctly
  * Fix crashes in UDPLink
  * Don't auto-connect to second Cube Orange/Yellow composite port
  * Plan: Fix bugs associated with mission commands which specify and altitude but no lat/lon
  * Fix bug which could prevent view switching from working after altitude mode warning dialog would pop up
* Mon Jul 27 2020 Michel Normand <normand@linux.vnet.ibm.com>
-  Add _constraints default min disk size & physicalmemory 4GB
* Tue Jun  2 2020 Adrian Schröter <adrian@suse.de>
- update to version 4.0.8
  * ** INCOMPATIBLE: All settings will be reset!
  Settings
    Language: Allow selection of language
    Optional CSV Logging of telemetry data for improved accessibility.
    ArduPilot: Mavlink: Configurable stream rate settings
  Setup
    Joystick
    New joystick setup ui
    Ability to configure held button to single or repeated action
    ArduPilot
    Motor Test
    ArduSub
    Automatic motor direction detection
  Plan
    Create Plan from template with wizard like progression for completing full Plan.
    Survey: Save commonly used settings as a Preset
    Polygon editing
    New editing tools ui
    Support for tracing a polygon from map locations
    ArduPilot
    Support for GeoFence and Rally Points using latest firmwares and mavlink v2
  Fly
    Click to ROI support
    Added support for connecting to ADSB SBS server. Adds support for ADSB data from USB SDR Dongle running 'dump1090 --net' for example.
    Ability to turn on Heading to home, COG and Next Waypoint heading indicators in Compass.
    Video
    Add support for h.265 video streams
    Automatically add a Video Overlay with flight data as a subtitle for locally-recorded videos
    Vehicle type specific pre-flight checklists. Turn on from Settings.
  Analyze
    New Mavlink Inspector which includes charting support. Supported on all builds including Android and iOS.
  General
    Released Windows build are now 64 bit only
    Log Replay: Ability to specify replay speed
    ArduPilot
    Improved support for chibios firmwares and ArduPilot bootloader with respect to flashing and auto-connect.
* Fri Jan 24 2020 Adrian Schröter <adrian@suse.de>
- update to current 3.6 pre-release code to support Qt 5.14
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel: allow
  OBS to shortcut through -mini flavors. Also drop the conditional
  BR, since the same symbol is also requried unconditionaly.
* Fri Oct 11 2019 Adrian Schröter <adrian@suse.de>
- update to 3.6 pre-release
  * fixes build for factory
  * dropping obsolete use_system_qwt.patch
  * require Qt 5.11 or higher
* Fri Aug 16 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.5.4
  * no release notes, bugfix release
* Sat Jun 29 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.5.3
  * no release notes, bugfix release
* Tue Mar  5 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.5.0
  * Overall
  - Bumped settings version (now 8). This will cause all settings to be reset to defaults.
  - Added Chinese and Turkish localization and partial German localization.
  - Added support for the Taisync 2.4GHz ViUlinx digital HD wireless link.
  - Fix loading of parameters from multiple components. This especially affected WiFi connections.
  - ArduPilot Support for ChibiOS firmware connect and flash.
  * Settings
  - RTK Add support for specifying fixed RTK based station location in Settings/General.
  - GCS Location
  - Added UDP Port option for NMEA GPS Device.
  - GCS heading shown if available
  * Plan
  - Polygons Support loading polygons from SHP files.
  - Fixed Wing Landing Pattern Add stop photo/video support. Defaults to on such that doing an RTL will stop camera.
  - Edit Position dialog Available on polygon vertices.
  * Fly
  - Camera Page Updated support for new MAVLInk camera messages. Camera select, camera mode, start/stop photo/video, storage mangement...
  - Orbit Support for changing rotation direction.
  - Instrument Panel
  - Added ESTIMATOR_STATUS values to new estimatorStatus Vehicle FactGroup. These are now available to display in instrument panel.
  - Make Distance to GCS available for display from instrument panel.
  - Make Heading to Home available for display from instrument panel.
* Wed Nov 28 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.4.4
  * minor bugfixes
* Mon Sep 17 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.4.3
  * Fix terrain NaN making it all the way to Planned Home altitude.
  * Fix Resume Mission item count bug
* Tue Sep  4 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.4.2
  * Settings
  - Offline Maps
  - Help Provides links to QGC user guide and forums.
  * Setup
  - Firmware Ability to flash either PX4 or ArduPilot Flow firmware.
  - PX4 Pro Firmware
  * Flight Modes Specify channels for all available transmitter switches.
  * Tuning: Advanced Initial implementation of vehicle PID tuning support. Note that this is a work in progress that will improve in 3.5 daily builds.
  - ArduPilot Firmware
  * Power/Safety Support for new multi-battery setup.
  * Trad Heli New setup page.
  * Plan
  - File Load/Save New model for Plan file loading which matches a standard File Load/Save/Save As user model.
  - Load KML Ability to load a KML file directly from the Sync menu. You will be prompted for what type of Pattern you want to create from the KML if needed.
  - Survey Better support for irregular shaped polygons.
  - Corridor Scan - Create a flight pattern which follows a poly-line. For example can be used to survey a road.
  - Fixed Wing Landing Pattern
  * Landing area visually represented in Plan.
  * Landing position/heading can be copied from Vehicle position/heading.
  - Terrain
  * Height of mission items can be specified as height above terrain.
  * Survey and Corridor Scan can generate flight plans which follow terrain.
  - Edit Position Set item position from vehicle position.
  * Fly
  - Pre-Flight Checklist You can turn this on from Settings. It provides a generic checklist to follow prior to flight. Expect more feature to appear for this in 3.5 daily builds.
  - Instrument Panel
  * Many new values available for display.
  * New Camera page which provides full camera control. Requires a camera which support new MavLink camera specification.
  - ArduPlane Much better support for guided commands including QuadPlane support.
  - High Latency Links Support for high latency links such as satelitte connections. Limits the traffic from QGC up to Vehicle on these links to reduce cost. Supports HIGH_LATENCY mavlink message. Supports failover back/forth from high latency to normal link with dual link setup.
* Thu May  3 2018 adrian@suse.de
- update to version 3.3.2
  * crash fixes and debugging improvements
* Fri Apr 13 2018 adrian@suse.de
- update to version 3.3.1
  * minor enhancements and bugfixes
* Wed Mar  7 2018 adrian@suse.de
- get rid of espeak
- use system qwt (submission by alois use_system_qwt.patch)
- add gstreamer dependencies
* Wed Mar  7 2018 adrian@suse.de
- update to version 3.3.0
  * Settings
  - Local NMEA GPS device support.
  - Video Recording save settings.
  * Setup
  - Parameter Editor - Searching updates as you type characters for near immediate response to searches.
  - Joystick - Android joystick support.
  * Plan
  - NEW - Structure Scan Pattern - Create a multi-layered flight pattern that captures images over vertical surfaces (polygonal or circular). Used for 3d model generation or vertical surface inspection.
  - Fixed Wing Landing Pattern - You can now adjust the distance from the loiter to land point by either distance or glide slope fall rate.
  - PX4 GeoFence and Rally Point support.
  - Terrain height display in lower Mission Item altitude display
  * Fly
  - Start/Stop video recording.
  - Better display of vehicle icons when connected to multiple vehicles.
  - Multi-Vehicle View supports commands which apply to all vehicles.
  - Displays vehicles reported from ADS-B sensor.
  * Analyze
  - Mavlink console - New support for communicating with Mavlink console.
  - Log Download - Moved from Menu to Analyze view.
- drop merged qt 5.10 fix (5923.patch)
* Mon Jan  1 2018 adrian@suse.de
- update to version 3.2.7
  * Bring fixes from master to Stable
  * Remove debuggable to hopefully get back auto-stable build update
- fixing build with Qt 5.10 with patch based on upstream pull request
  (5923.patch)
* Mon Nov  6 2017 adrian@suse.de
- update to version 3.2.5
* Thu Oct 12 2017 jengelh@inai.de
- Trim project history from description.
  Replace %%__-type macro indirections.
  Avoid running fdupes across partition boundaries.
* Wed Aug  9 2017 adrian@suse.de
- update to verion 3.2.4
* Mon Feb 27 2017 adrian@suse.de
- add desktop file again
* Fri Feb 17 2017 adrian@suse.de
- update to version 3.1.3
* Fri Oct 28 2016 adrian@suse.de
- update to version 3.0.2
* Wed Jul 27 2016 adrian@suse.de
- update to version 3.0.0
* Wed May 11 2016 adrian@suse.de
- update to version 2.9.7b
  * Fixed condition for arming button
* Tue May 10 2016 adrian@suse.de
- update to version 2.9.7
  * Fix takeoff logic
  * flight display updates
  * PX4: Fix guided mode interaction
* Mon May  9 2016 adrian@suse.de
- update to version 2.9.6
  * adds a configurable mag calibration for PX4
  * Flight mode updates for APM
  * Simpler mag calibration for PX4
  * (Many changes for mobile version, no effect in this build)
* Fri Feb 26 2016 adrian@suse.de
- update to version 2.9.4
  * looks like feature release, but no changelog
* Mon Feb  1 2016 adrian@suse.de
- update to version 2.9.2
  * bugfix release
* Mon Jan 25 2016 adrian@suse.de
- update to version 2.9.0
  * auto-connect
  * full PX4 and APM stack support including config
  * general improvement
- add conflict to ModemManager, tired of the caused breakage
  (is anyone still using modems at all?)
* Tue Jan  5 2016 adrian@suse.de
- update to version 2.8.0
  * MainWindow
  * Major rewrite of Fly and Mission Editor views
  * Desktop widgets now float instead of dock
  * New Joystick Config
  * PX4 Flow Config
  * Search support
  * Reset to default
  * Flash of APM Stack firmware
  * Flash of PX4 Flow support custom firmware
  * Major visual overhaul
  * Arm/Disarm and change Flight Mode from toolbar
  * Major work on ui display with multiple screen sizes
  * Android builds are now very usable
  * New Travis/Appveyor CI build system
* Thu Aug 20 2015 adrian@suse.de
- update to version 2.7.1
* Mon Jul 27 2015 adrian@suse.de
- update to version 2.6
* Wed Mar 25 2015 adrian@suse.de
- update to version 2.3
- fix build
* Thu Dec 25 2014 christoph@stop.pe
- Initial version
